# import package
library(sna)

# load data
load('~/Documents/python/social_network_analysis/studentnets.mrqap173.rda')
# print all data names
ls()

# transform into an matrix
m173_sem1_SSL <- as.matrix(m173_sem1_SSL)
m173_sem1_TSL <- as.matrix(m173_sem1_TSL)
m173_sem1_FRN <- as.matrix(m173_sem1_FRN)
m173_sem1_SEAT <- as.matrix(m173_sem1_SEAT)
m173_sem1_RCE <- as.matrix(m173_sem1_RCE)
m173_sem1_GND <- as.matrix(m173_sem1_GND)

m173_sem2_SSL <- as.matrix(m173_sem2_SSL)
m173_sem2_TSL <- as.matrix(m173_sem2_TSL)

# create a predictor matrix
predictor_matrices <- array(NA, c(6, length(m173_sem1_SSL[1,]),length(m173_sem1_SSL[1,]))) 
# OR: predictor_matrices <- array(NA, c(6, 26,26))

predictor_matrices[1,,] <- m173_sem1_SSL
predictor_matrices[2,,] <- m173_sem1_TSL
predictor_matrices[3,,] <- m173_sem1_FRN
predictor_matrices[4,,] <- m173_sem1_SEAT
predictor_matrices[5,,] <- m173_sem1_RCE
predictor_matrices[6,,] <- m173_sem1_GND

# Fit a netlm model: the response matrix and the array of predictor matrices
nl<-netlm(m173_sem2_SSL, predictor_matrices)

# Make the model easier to read
nlLabeled <- list()
nlLabeled <- summary(nl)

# adding labels
nlLabeled$names <- c("Intercept", "SSL1", "TSL1", "Friends", "Seat","Race","Gender")

# Round the coefficients to two decimals
nlLabeled$coefficients = round(nlLabeled$coefficients, 2)
nlLabeled

# plot distribution
par(mfrow = c(2, 4))
for(i in 1:7){
  hist_obj<-hist(nlLabeled$dist[,i], main = nlLabeled$names[i], 
                 xlab = nlLabeled$names[i])
  lines(cbind(nlLabeled$tstat[i], nlLabeled$tstat[i]), 
        cbind(0, max(hist_obj$counts)), col='blue', lwd=2)
}

# Fit a netlm model: the response matrix and the array of predictor matrices
n2<-netlm(m173_sem2_TSL, predictor_matrices)

# Make the model easier to read
n2Labeled <- list()
n2Labeled <- summary(n2)

# adding labels
n2Labeled$names <- c("Intercept", "SSL1", "TSL1", "Friends", "Seat","Race","Gender")

# Round the coefficients to two decimals
n2Labeled$coefficients = round(n2Labeled$coefficients, 2)
n2Labeled

# plot distribution
par(mfrow = c(2, 4))
for(i in 1:7){
  hist_obj<-hist(n2Labeled$dist[,i], main = n2Labeled$names[i], 
                   xlab = n2Labeled$names[i])
  lines(cbind(n2Labeled$tstat[i], n2Labeled$tstat[i]), 
       cbind(0, max(hist_obj$counts)), col='blue', lwd=2)
}
